==> igloo_0_1_2.tar.tgz: igloo_0_1_2/igloo/language/1/barnraiser_01/spl_view.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common.lang.php');


//HDR
$lang['hdr_welcome'] = 						"welcome";
$lang['hdr_membership'] = 					"your membership";
$lang['hdr_profile'] = 						"your profiles";
$lang['hdr_friends'] = 						"your network";
$lang['hdr_help'] = 						"get help";
$lang['hdr_credits'] = 						"credits";
$lang['hdr_about_Igloo'] = 					"about Igloo";
$lang['hdr_man'] = 							"guide for this software";
$lang['hdr_login'] = 						"login";
$lang['hdr_password'] = 					"forgotten password?";


//A HREF TAGS (links)
$lang['href_membership'] = 					"update your membership";
$lang['href_profile'] = 					"update your profiles";
$lang['href_friends'] = 					"invite more friends";
$lang['href_help1'] = 						"visit your help pages";


//BODY TEXT
$lang['txt_introduction'] = 				"<h3>Welcome to Igloo; Interest group glue! The free Interest group social networking and collaboration platform!</h3><p>Igloo is the perfect solution for mutual interest (MIG) and special interest (SIG) groups and membership based organisations wishing to create a knowledge network around their interests.</p><p>Members can create and publishing blogs, wiki pages, polls, discussions, channels, tasks and activities to either their network, the group or to the public. These tools are integrated tightly into a simple to use platform enabling you to empower your membership around your shared interests.</p><p>This is a pre-release demo for you to look at. Do not expect much at this stage of the development cycle! You can log in using the email address <b>demo@barnraiser.org</b> and the password <b>demo4me</b>.</p>";

$lang['txt_membership_introduction'] = 		"Update your membership information including your home page (the first page you arrive at). Remember this information is only accessible by system administrators and is used to maintain your membership.";
$lang['txt_profile_introduction'] = 		"Update your default profiles or add profiles. You may wish to have a profile for your friends and a separate profile for each group you join.";
$lang['txt_friends_introduction'] = 		"Add more friends. By increasing your social network you build a valuable knowledge network.";
$lang['txt_help_introduction'] = 			"Help is always available to you through your help wiki pages.";
$lang['txt_welcome'] = 						"welcome";
$lang['txt_credits'] = 						"Igloo was conceived by Tom Calthrop, founder of Barnraiser and 'Igloo' project maintainer. Many thanks to the developers who have given time, energy and expertise to the Igloo project!";
$lang['txt_about_Igloo'] = 					"Barnraiser is an organisation dedicated to giving people the tools they need to share knowledge and advance society through social software.<br /><p>As part of their mission they maintain 'Igloo', the software platform that this community is build upon.<br /></p><p>Visit Barnraiser at <a href=\"http://www.barnraiser.org/\" target=\"_new\">www.barnraiser.org</a> to find out more about their work.<br /></p>";
$lang['txt_public_introduction'] = 			"<h3>Welcome to Igloo; Interest group glue! The free Interest group social networking and collaboration platform!</h3><p>Igloo is the perfect solution for mutual interest (MIG) and special interest (SIG) groups and membership based organisations wishing to create a knowledge network around their interests.</p><p>Members can create and publishing blogs, wiki pages, polls, discussions, channels, tasks and activities to either their network, the group or to the public. These tools are integrated tightly into a simple to use platform enabling you to empower your membership around your shared interests.</p><p>This is a pre-release demo for you to look at. Do not expect much at this stage of the development cycle! You can log in using the email address <b>demo@barnraiser.org</b> and the password <b>demo4me</b>.</p>";
$lang['txt_email'] = 						"your email address";
$lang['txt_password'] = 					"your password";
$lang['txt_new_password'] = 				"If you have forgotten your password you can <a href =\"new_password.php\">get a new password here</a>.";
$lang['txt_login_note'] = 					"You will remain logged in until you press 'logoff' or exit the browser.";


?>

==> igloo_0_1_5.tar.tgz: igloo_0_1_5/igloo/language/1/barnraiser_01/spl_view.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common.lang.php');


//HDR
$lang['hdr_welcome'] = 						"welcome";
$lang['hdr_membership'] = 					"your membership";
$lang['hdr_profile'] = 						"your profiles";
$lang['hdr_friends'] = 						"your network";
$lang['hdr_help'] = 						"get help";
$lang['hdr_credits'] = 						"credits";
$lang['hdr_about_Igloo'] = 					"about Igloo";
$lang['hdr_man'] = 							"guide for this software";
$lang['hdr_login'] = 						"login";
$lang['hdr_password'] = 					"forgotten password?";


//A HREF TAGS (links)
$lang['href_membership'] = 					"update your membership";
$lang['href_profile'] = 					"update your profiles";
$lang['href_friends'] = 					"invite more friends";
$lang['href_help1'] = 						"visit your help pages";


//BODY TEXT
$lang['txt_introduction'] = 				"<h3>Welcome to Igloo; Interest group glue! The free Interest group social networking and collaboration platform!</h3><p>Igloo is the perfect solution for mutual interest (MIG) and special interest (SIG) groups and membership based organisations wishing to create a knowledge network around their interests.</p><p>Members can create and publish blogs, wiki pages, polls, discussions, channels, tasks and activities to either their network, the group or to the public. These tools are integrated tightly into a simple to use platform enabling you to empower your membership around your shared interests.</p><p>This is a pre-release demo for you to look at. Do not expect much at this stage of the development cycle! You can log in using the email address <b>demo@barnraiser.org</b> and the password <b>demo4me</b>.</p>";

$lang['txt_membership_introduction'] = 		"Update your membership information including your home page (the first page you arrive at). Remember this information is only accessible by system administrators and is used to maintain your membership.";
$lang['txt_profile_introduction'] = 		"Update your default profiles or add profiles. You may wish to have a profile for your friends and a separate profile for each group you join.";
$lang['txt_friends_introduction'] = 		"Add more friends. By increasing your social network you build a valuable knowledge network.";
$lang['txt_help_introduction'] = 			"Help is always available to you through your help wiki pages.";
$lang['txt_welcome'] = 						"welcome";
$lang['txt_credits'] = 						"Igloo was conceived by Tom Calthrop, founder of Barnraiser and 'Igloo' project maintainer. Many thanks to the developers who have given time, energy and expertise to the Igloo project!";
$lang['txt_about_Igloo'] = 					"Barnraiser is an organisation dedicated to giving people the tools they need to share knowledge and advance society through social software.<br /><p>As part of their mission they maintain 'Igloo', the software platform that this community is build upon.<br /></p><p>Visit Barnraiser at <a href=\"http://www.barnraiser.org/\" target=\"_new\">www.barnraiser.org</a> to find out more about their work.<br /></p>";
$lang['txt_public_introduction'] = 			"<h3>Welcome to Igloo; Interest group glue! The free Interest group social networking and collaboration platform!</h3><p>Igloo is the perfect solution for mutual interest (MIG) and special interest (SIG) groups and membership based organisations wishing to create a knowledge network around their interests.</p><p>Members can create and publish blogs, wiki pages, polls, discussions, channels, tasks and activities to either their network, the group or to the public. These tools are integrated tightly into a simple to use platform enabling you to empower your membership around your shared interests.</p><p>This is a pre-release demo for you to look at. Do not expect much at this stage of the development cycle! You can log in using the email address <b>demo@barnraiser.org</b> and the password <b>demo4me</b>.</p>";
$lang['txt_email'] = 						"your email address";
$lang['txt_password'] = 					"your password";
$lang['txt_new_password'] = 				"If you have forgotten your password you can <a href =\"new_password.php\">get a new password here</a>.";
$lang['txt_login_note'] = 					"You will remain logged in until you press 'logoff' or exit the browser.";


?>
